@@ -25,7 +25,7 @@ You need to register the correct version listed in `Supported Resources`.
 |            | Datadog-AWS integration | `Datadog::Integrations::AWS`     | [Manage your Datadog-Amazon Web Service integration.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-integrations-aws-handler) | N/A                |
 |     ✅     | Monitors                | `Datadog::Monitors::Monitor`     | [Create, update, and delete Datadog monitors.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-monitors-monitor-handler)        | [3.0.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-monitors-monitor-handler/CHANGELOG.md#300--2021-02-16)         |
 |     ✅     | Downtimes               | `Datadog::Monitors::Downtime`    | [Enable or disable downtimes for your monitors.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-monitors-downtime-handler)      | [2.0.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-monitors-downtime-handler/CHANGELOG.md#200--2021-02-16)         |
-|     ✅     | User                    | `Datadog::IAM::User`             | [Create and manage Datadog users.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-iam-user-handler)                    | [1.2.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-iam-user-handler/CHANGELOG.md#120--2021-02-16)         |
+|     ✅     | Users                   | `Datadog::IAM::User`             | [Create and manage Datadog users.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-iam-user-handler)                    | [1.2.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-iam-user-handler/CHANGELOG.md#120--2021-02-16)         |
 
 ## Installation
 
@@ -96,6 +96,41 @@ DatadogMonitor(your_stack, "TestMonitor",
     }
 )
 ```
+
+### Downtimes
+
+```python
+# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
+from nomadblacky.cdk_datadog_resources import DatadogDowntime
+
+DatadogDowntime(stack, "TestMonitor",
+    datadog_credentials={
+        "api_key": "DATADOG_API_KEY",
+        "application_key": "DATADOG_APP_KEY"
+    },
+    scope=["host:myserver", "service:myservice"],
+    start=1624542715,
+    end=1624546321
+)
+```
+
+### Users
+
+```python
+# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
+from nomadblacky.cdk_datadog_resources import DatadogIAMUser
+
+DatadogIAMUser(stack, "TestUser",
+    datadog_credentials={
+        "api_key": "DATADOG_API_KEY",
+        "application_key": "DATADOG_APP_KEY"
+    },
+    email="jane.doe@example.com",
+    name="name_example",
+    handle="title_example",
+    disabled=False
+)
+```
 '''
 import abc
 import builtins
